@@ -355,7 +355,7 @@ parse_queries(const string& oldp)
 	    qp.set_stemming_strategy(Xapian::QueryParser::STEM_ALL);
 	}
     }
-    qp.set_stopper(new MyStopper());
+    qp.set_stopper((new MyStopper())->release());
     qp.set_default_op(default_op);
     qp.set_database(db);
     // FIXME: provide a custom RP which handles size:10..20K, etc.
@@ -2483,7 +2483,7 @@ eval(const string &fmt, const vector<string> &param)
     } catch (const Xapian::Error & e) {
 	// FIXME: this means we only see the most recent error in $error
 	// - is that the best approach?
-	error_msg = e.get_msg();
+	error_msg = e.get_description();
     }
 
     res.append(fmt, p, string::npos);
@@ -2583,12 +2583,6 @@ void
 parse_omegascript()
 {
     try {
-	const char * p = getenv("SERVER_PROTOCOL");
-	if (p && strcmp(p, "INCLUDED") == 0) {
-	    // We're being included in another page, so suppress headers.
-	    suppress_http_headers = true;
-	}
-
 	string output = eval_file(fmtname);
 	if (!set_content_type && !suppress_http_headers) {
 	    cout << "Content-Type: text/html" << endl;
